"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeBrackets = (v) => v.replace(/[<[].+/, '').trim();
exports.findAllBrackets = (v) => {
    const ANGLED_BRACKET_RE_GLOBAL = /<([^>]+)>/g;
    const SQUARE_BRACKET_RE_GLOBAL = /\[([^\]]+)\]/g;
    const res = [];
    const parse = (match) => {
        let variadic = false;
        let value = match[1];
        if (value.startsWith('...')) {
            value = value.slice(3);
            variadic = true;
        }
        return {
            required: match[0].startsWith('<'),
            value,
            variadic
        };
    };
    let angledMatch;
    while ((angledMatch = ANGLED_BRACKET_RE_GLOBAL.exec(v))) {
        res.push(parse(angledMatch));
    }
    let squareMatch;
    while ((squareMatch = SQUARE_BRACKET_RE_GLOBAL.exec(v))) {
        res.push(parse(squareMatch));
    }
    return res;
};
exports.getMriOptions = (globalCommand, subCommand) => {
    const options = [
        ...globalCommand.options,
        ...(subCommand ? subCommand.options : [])
    ];
    const ignoreDefault = subCommand && subCommand.config.ignoreOptionDefaultValue
        ? subCommand.config.ignoreOptionDefaultValue
        : globalCommand.config.ignoreOptionDefaultValue;
    return {
        default: ignoreDefault
            ? {}
            : options.reduce((res, option) => {
                if (option.config.default !== undefined) {
                    // Only need to set the default value of the first name
                    // Since mri will automatically do the rest for alias names
                    res[option.names[0]] = option.config.default;
                }
                return res;
            }, {}),
        boolean: options
            .filter(option => option.isBoolean)
            .reduce((res, option) => {
            return res.concat(option.names);
        }, []),
        alias: options.reduce((res, option) => {
            if (option.names.length > 1) {
                res[option.names[0]] = option.names.slice(1);
            }
            return res;
        }, {})
    };
};
exports.findLongest = (arr) => {
    return arr.sort((a, b) => {
        return a.length > b.length ? -1 : 1;
    })[0];
};
exports.padRight = (str, length) => {
    return str.length >= length ? str : `${str}${' '.repeat(length - str.length)}`;
};
exports.camelcase = (input) => {
    return input.replace(/([a-z])-([a-z])/g, (_, p1, p2) => {
        return p1 + p2.toUpperCase();
    });
};
exports.setDotProp = (obj, keys, val) => {
    let i = 0;
    let length = keys.length;
    let t = obj;
    let x;
    for (; i < length; ++i) {
        x = t[keys[i]];
        t = t[keys[i]] =
            i === length - 1
                ? val
                : x != null
                    ? x
                    : !!~keys[i + 1].indexOf('.') || !(+keys[i + 1] > -1)
                        ? {}
                        : [];
    }
};
